using System.Collections.Generic;
using EasingFunction = System.Func<float, float>;

namespace MoonWorks.Audio
{
	internal enum AudioTweenProperty
	{
		Pan,
		Pitch,
		Volume,
		FilterFrequency,
		Reverb
	}

	internal class AudioTween
	{
		public System.WeakReference<SoundInstance> SoundInstanceReference;
		public AudioTweenProperty Property;
		public EasingFunction EasingFunction;
		public float Time;
		public float Start;
		public float End;
		public float Duration;
	}

	internal class AudioTweenPool
	{
		private Queue<AudioTween> Tweens = new Queue<AudioTween>();

		public AudioTween Obtain()
		{
			if (Tweens.Count > 0)
			{
				var tween = Tweens.Dequeue();
				return tween;
			}
			else
			{
				return new AudioTween();
			}
		}

		public void Free(AudioTween tween)
		{
			Tweens.Enqueue(tween);
		}
	}
}
